module.exports = defineTest({
	description: 'does not fail when non-integer arguments properties are accessed'
});
